@@ -19,6 +19,9 @@ SEARCH_COLUMN = 7
 
 THEME_PATH = "/usr/share/themes/default"
 
+import i18n
+_ = i18n.language.gettext
+
 class MussorgskyEditPanel (hildon.StackableWindow):
 
     def __init__ (self):
@@ -32,6 +35,7 @@ class MussorgskyEditPanel (hildon.StackableWindow):
         self.data_loaded = False
         self.artist_list = None
         self.albums_list = None
+        self.current = None
         self.connect ("delete-event", self.close_function)
 
     def close_function (self, widget, event):
@@ -43,8 +47,8 @@ class MussorgskyEditPanel (hildon.StackableWindow):
 
         
     def update_title (self):
-        self.set_title ("Edit (%d/%d)" % (self.model.get_path (self.current)[0] + 1,
-                                          len (self.model)))
+        self.set_title (_("Edit song") + " (%d/%d)" % (self.model.get_path (self.current)[0] + 1,
+                                                       len (self.model)))
 
     def get_current_row (self):
         if (not self.current):
@@ -143,16 +147,16 @@ class MussorgskyEditPanel (hildon.StackableWindow):
                                                  escape_html (artist) + " / " + escape_html (album))
         search_str = artist.lower () + " " + title.lower () + " " + album.lower ()
 
+        uri, mime = m.get (c, URI_COLUMN, MIME_COLUMN)
         m.set (c,
                ARTIST_COLUMN, artist,
                TITLE_COLUMN, title,
                ALBUM_COLUMN, album,
                UI_COLUMN, text,
                SEARCH_COLUMN, search_str)
-        new_song = self.get_current_row ()
         try:
-            self.writer.save_metadata_on_file (new_song[URI_COLUMN],
-                                               new_song[MIME_COLUMN],
+            self.writer.save_metadata_on_file (uri,
+                                               mime, 
                                                self.artist_button.get_value (),
                                                self.title_entry.get_text (),
                                                self.album_button.get_value ())
@@ -194,7 +198,7 @@ class MussorgskyEditPanel (hildon.StackableWindow):
         view_vbox.pack_start (central_panel, expand=True, fill=True)
 
         # Title row
-        label_title = gtk.Label ("Title:")
+        label_title = gtk.Label (_("Title:"))
         table.attach (label_title, 0, 1, 0, 1, 0)
         self.title_entry = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
         table.attach (self.title_entry, 1, 2, 0, 1)
@@ -202,7 +206,7 @@ class MussorgskyEditPanel (hildon.StackableWindow):
         # Artist row
         self.artist_button = hildon.PickerButton (gtk.HILDON_SIZE_THUMB_HEIGHT,
                                                   hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
-        self.artist_button.set_title ("Artist: ")
+        self.artist_button.set_title (_("Artist:"))
         # Set data will set the selector
         table.attach (self.artist_button, 0, 2, 1, 2)
 
@@ -210,7 +214,7 @@ class MussorgskyEditPanel (hildon.StackableWindow):
         # Album row
         self.album_button = hildon.PickerButton (gtk.HILDON_SIZE_THUMB_HEIGHT,
                                                  hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
-        self.album_button.set_title ("Album: ")
+        self.album_button.set_title (_("Album:"))
         # set_data will set the selector
         table.attach (self.album_button, 0, 2, 2, 3)
         
